(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('diff-match-patch'), require('diff2html'), require('@angular/platform-browser')) :
    typeof define === 'function' && define.amd ? define('ngx-diff2html', ['exports', '@angular/core', 'diff-match-patch', 'diff2html', '@angular/platform-browser'], factory) :
    (global = global || self, factory(global['ngx-diff2html'] = {}, global.ng.core, global['diff-match-patch'], global.diff2html, global.ng.platformBrowser));
}(this, (function (exports, core, diffMatchPatch, diff2html, platformBrowser) { 'use strict';

    /**
     * @fileoverview added by tsickle
     * Generated from: lib/ngx-diff2html.service.ts
     * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    var NgxDiff2htmlService = /** @class */ (function () {
        function NgxDiff2htmlService() {
        }
        /**
         * @param {?} text1
         * @param {?} text2
         * @param {?=} filename
         * @return {?}
         */
        NgxDiff2htmlService.prototype.getDiff = /**
         * @param {?} text1
         * @param {?} text2
         * @param {?=} filename
         * @return {?}
         */
        function (text1, text2, filename) {
            if (filename === void 0) { filename = ''; }
            // Get diff
            /** @type {?} */
            var dmp = new diffMatchPatch.diff_match_patch();
            /** @type {?} */
            var chars = dmp.diff_linesToChars_(text1, text2);
            /** @type {?} */
            var lineText1 = chars.chars1;
            /** @type {?} */
            var lineText2 = chars.chars2;
            /** @type {?} */
            var lineArray = chars.lineArray;
            /** @type {?} */
            var diffs = dmp.diff_main(lineText1, lineText2, false);
            dmp.diff_charsToLines_(diffs, lineArray);
            /** @type {?} */
            var patchMake = dmp.patch_make(text1, diffs);
            /** @type {?} */
            var patchToText = dmp.patch_toText(patchMake);
            // console.info(patchToText);
            // Make it look more like a unified diff style
            // ToDo: find a non tricky way to do this
            /** @type {?} */
            var lines = patchToText.split("\n");
            lines.forEach((/**
             * @param {?} line
             * @param {?} index
             * @return {?}
             */
            function (line, index) {
                if (line.startsWith('-')) {
                    lines[index] = line.replace(/%0A(.)/g, "%0A-$1");
                }
                else if (line.startsWith('+')) {
                    lines[index] = line.replace(/%0A(.)/g, "%0A+$1");
                }
            }));
            /** @type {?} */
            var unifiedDiff = lines.join("\n");
            // console.info(unifiedDiff);
            /** @type {?} */
            var strInput = "--- " + filename + " \n+++ " + filename + " \n" + unifiedDiff;
            /** @type {?} */
            var diff = decodeURIComponent(strInput);
            // console.info(diff);
            // Return diff
            return diff;
        };
        /**
         * @param {?} diff
         * @param {?=} format
         * @param {?=} style
         * @return {?}
         */
        NgxDiff2htmlService.prototype.diffToHTML = /**
         * @param {?} diff
         * @param {?=} format
         * @param {?=} style
         * @return {?}
         */
        function (diff, format, style) {
            if (format === void 0) { format = 'line-by-line'; }
            if (style === void 0) { style = 'word'; }
            return diff2html.html(diff, {
                drawFileList: false,
                matching: 'lines',
                outputFormat: format,
                diffStyle: style
            });
        };
        NgxDiff2htmlService.decorators = [
            { type: core.Injectable, args: [{
                        providedIn: 'root'
                    },] }
        ];
        /** @nocollapse */
        NgxDiff2htmlService.ctorParameters = function () { return []; };
        /** @nocollapse */ NgxDiff2htmlService.ngInjectableDef = core.ɵɵdefineInjectable({ factory: function NgxDiff2htmlService_Factory() { return new NgxDiff2htmlService(); }, token: NgxDiff2htmlService, providedIn: "root" });
        return NgxDiff2htmlService;
    }());

    /**
     * @fileoverview added by tsickle
     * Generated from: lib/ngx-diff2html.component.ts
     * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    var NgxDiff2htmlComponent = /** @class */ (function () {
        function NgxDiff2htmlComponent(diffService) {
            this.diffService = diffService;
            this.filename = '';
            this.format = 'line-by-line';
            this.style = 'word';
            this.diffChange = new core.EventEmitter();
            this.diff = null;
            this.diffHTML = null;
        }
        /**
         * @return {?}
         */
        NgxDiff2htmlComponent.prototype.ngOnInit = /**
         * @return {?}
         */
        function () {
            this.getDiff();
        };
        /**
         * @param {?} changes
         * @return {?}
         */
        NgxDiff2htmlComponent.prototype.ngOnChanges = /**
         * @param {?} changes
         * @return {?}
         */
        function (changes) {
            //console.log(changes);
            if (this.propHasChanged(changes.left) || this.propHasChanged(changes.right)) {
                this.getDiff();
            }
            else if (this.propHasChanged(changes.style) || this.propHasChanged(changes.format)) {
                this.refreshDiffHTML();
            }
        };
        /**
         * @private
         * @param {?} change
         * @return {?}
         */
        NgxDiff2htmlComponent.prototype.propHasChanged = /**
         * @private
         * @param {?} change
         * @return {?}
         */
        function (change) {
            return change && !change.isFirstChange() && change.currentValue !== change.previousValue;
        };
        /**
         * @return {?}
         */
        NgxDiff2htmlComponent.prototype.getDiff = /**
         * @return {?}
         */
        function () {
            this.diff = this.diffService.getDiff(this.left, this.right, this.filename);
            this.refreshDiffHTML();
            this.diffChange.emit(this.diff);
        };
        /**
         * @return {?}
         */
        NgxDiff2htmlComponent.prototype.refreshDiffHTML = /**
         * @return {?}
         */
        function () {
            this.diffHTML = this.diffService.diffToHTML(this.diff, this.format, this.style);
        };
        NgxDiff2htmlComponent.decorators = [
            { type: core.Component, args: [{
                        selector: 'ngx-diff2html',
                        template: "\n    <div [innerHtml]=\"diffHTML | safe:'html'\"></div>\n  "
                    }] }
        ];
        /** @nocollapse */
        NgxDiff2htmlComponent.ctorParameters = function () { return [
            { type: NgxDiff2htmlService }
        ]; };
        NgxDiff2htmlComponent.propDecorators = {
            left: [{ type: core.Input }],
            right: [{ type: core.Input }],
            filename: [{ type: core.Input }],
            format: [{ type: core.Input }],
            style: [{ type: core.Input }],
            diffChange: [{ type: core.Output }]
        };
        return NgxDiff2htmlComponent;
    }());
    if (false) {
        /**
         * @type {?}
         * @private
         */
        NgxDiff2htmlComponent.prototype.left;
        /**
         * @type {?}
         * @private
         */
        NgxDiff2htmlComponent.prototype.right;
        /**
         * @type {?}
         * @private
         */
        NgxDiff2htmlComponent.prototype.filename;
        /**
         * @type {?}
         * @private
         */
        NgxDiff2htmlComponent.prototype.format;
        /**
         * @type {?}
         * @private
         */
        NgxDiff2htmlComponent.prototype.style;
        /** @type {?} */
        NgxDiff2htmlComponent.prototype.diffChange;
        /**
         * @type {?}
         * @private
         */
        NgxDiff2htmlComponent.prototype.diff;
        /** @type {?} */
        NgxDiff2htmlComponent.prototype.diffHTML;
        /**
         * @type {?}
         * @private
         */
        NgxDiff2htmlComponent.prototype.diffService;
    }

    /**
     * @fileoverview added by tsickle
     * Generated from: pipes/safe.pipe.ts
     * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    var SafePipe = /** @class */ (function () {
        function SafePipe(sanitizer) {
            this.sanitizer = sanitizer;
        }
        /**
         * @param {?} value
         * @param {?} type
         * @return {?}
         */
        SafePipe.prototype.transform = /**
         * @param {?} value
         * @param {?} type
         * @return {?}
         */
        function (value, type) {
            switch (type) {
                case 'html':
                    return this.sanitizer.bypassSecurityTrustHtml(value);
                case 'style':
                    return this.sanitizer.bypassSecurityTrustStyle(value);
                case 'script':
                    return this.sanitizer.bypassSecurityTrustScript(value);
                case 'url':
                    return this.sanitizer.bypassSecurityTrustUrl(value);
                case 'resourceUrl':
                    return this.sanitizer.bypassSecurityTrustResourceUrl(value);
                default:
                    throw new Error("SafePipe unable to bypass security for invalid type: " + type);
            }
        };
        SafePipe.decorators = [
            { type: core.Pipe, args: [{
                        name: 'safe',
                        pure: true
                    },] }
        ];
        /** @nocollapse */
        SafePipe.ctorParameters = function () { return [
            { type: platformBrowser.DomSanitizer }
        ]; };
        return SafePipe;
    }());
    if (false) {
        /**
         * @type {?}
         * @protected
         */
        SafePipe.prototype.sanitizer;
    }

    /**
     * @fileoverview added by tsickle
     * Generated from: lib/ngx-diff2html.module.ts
     * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    var NgxDiff2htmlModule = /** @class */ (function () {
        function NgxDiff2htmlModule() {
        }
        NgxDiff2htmlModule.decorators = [
            { type: core.NgModule, args: [{
                        declarations: [
                            NgxDiff2htmlComponent,
                            SafePipe
                        ],
                        imports: [],
                        exports: [
                            NgxDiff2htmlComponent
                        ]
                    },] }
        ];
        return NgxDiff2htmlModule;
    }());

    exports.NgxDiff2htmlComponent = NgxDiff2htmlComponent;
    exports.NgxDiff2htmlModule = NgxDiff2htmlModule;
    exports.NgxDiff2htmlService = NgxDiff2htmlService;
    exports.ɵa = SafePipe;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-diff2html.umd.js.map
